/*                       SCL1.LIB's Mouse Functions Demo

	To run this demo inside QuickC environment:

		Copy SCL1.H into your INCLUDE subdirectory.
		Load your Mouse Driver.
		Load SCL1 Quick Library.
		Turn Screen Swapping On (QC's Debug Menu).
		Compile it (memory output option and debug option on if you
					want to step through).


		To Load SCL1 Quick Library:

			qc /l scl1

	File SCL1.QLB must be located in the path specified in the LIB
	environment variable directory or in your default drive/path

	*/

#include <scl1.h>

/* Buffer for saving pop-up menus screen area */

char WinBuffer[88];

/* Bar Menu structure */

struct BarMenu bm[]={
    2,8,"F1 Main",
    16,24,"F2 Screen",
    };

/* Pop-up menu structures */

struct MenuOpt Menu1[]={
	2,3," Quit ",'Q'          /* Line,Column,String,Letter */
    };

struct MenuOpt Menu2[]={
	2,17," Paint ",'P',
	3,17," Clear ",'C'
    };

/* Pop-up menu box/window data */

struct PopMenuData pmd[]={
	1,1,3,10,               /* Top Left corner - Bottom right corner */
	1,                      /* Number of options  */
	WinBuffer,              /* Window buffer */
	Menu1,                  /* Menu structure */

    1,15,4,25,
    2,
    WinBuffer,
    Menu2,
    };

/* This structure links all previous structures in to one menu system */

struct MenuSysData msd[]={
	F1,                     /* First Menu Key */
	&pmd[0],                /* First Menu structure */

	F2,                     /* Second Menu key */
	&pmd[1],                /* structure */
    };

struct MouseButton mb[]={   /* QUIT mouse button structure */
	16,1,18,78,             /* Box area */
	17,38,"QUIT",           /* Message position & string */
	};

/* Menu colors = 1-3, Bottom Box Color = 4 ,Color6 = Paint Color*/

char Color1=WHITE_BLUE,Color2=BLACK_WHITE,Color3=WHITE_BLUE+HIGHLIGHT,Color4=CYAN_BLACK,Color5=WHITE_RED,Color6=WHITE_RED;

char Buffer[3];

main()
{
int X1,Y1,X2,Y2;
int OldLPX=-1,OldLPY=-1,OldLRX=-1,OldLRY=-1,OldRPX=-1,OldRPY=-1,OldRRX=-1,OldRRY=-1,OldMX=-1,OldMY=-1,OldLP=-1,OldLR=-1,OldRP=-1,OldRR=-1,OldMM=-1;
int Selection,PaintFlag,EndFlag=0;

/* Turn cursor off */

CursorOff();

/* Color or Mono?, change color to B&W in case of Mono */

if (Video()==MONO)
	Color1=Color4=Color5=WHITE_BLACK,Color3=WHITE_BLACK+HIGHLIGHT,Color6=BLACK_WHITE;

/* Is Mouse installed?, CheckMouse returns 0 if no */

if (CheckMouse())
    {
	ResetMouse();   /*Reset mouse to defaults */
	SetMouseIsr();  /* Enable SCL1's mouse related functions */
	SetMousePos(0,0);
	}

/* Clear screen area */

Cls(Color4,0,0,24,79);

/* Draw Bar Menu
	Parameters: Normal Color, Selected Color, Number of Items,
				Selected Item(0=None), BarMenu structure */

DrawBarMenu(Color1,Color2,2,0,bm);

/* Draw Bottom Box */

Box(Color4,3,15,0,24,79);

/* Draw QUIT Mouse Button
	Parameters: Normal Color, Selected Color, Number of Buttons,
				Selected Button(0=None), MouseButton structure */

DrawMouseButton(Color4,Color5,1,0,mb);


WriteScreen(Color4,19,3," LEFT_PRESS\n   LEFT_REL\nRIGHT_PRESS\n  RIGHT_REL\n MOUSE_MOVE");
WriteScreen(Color4,19,35,"  LPX\n  LRX\n  RPX\n  RRX\nMOVEX");
WriteScreen(Color4,19,59,"  LPY\n  LRY\n  RPY\n  RRY\nMOVEY");

/* If CheckMouse found a mouse installed variable MOUSE_FLAG was set to 1
   if so, Turn mouse cursor on and limit vertical mouse movement between
   line 0 and line 18 */

if (MOUSE_FLAG)
    {
    ShowMouse();
	SetVerLimit(0,18);
	do

  /*    Here is the program main loop, it checks variables declared in
		SCL1's mouse functions to check mouse actual condition */


        {
		if(OldLP!=LEFT_PRESS)
            {
			if (LEFT_PRESS==1)                    /*LEFT_PRESS=1 if left */
				WriteScreen(Color2,19,15,"YES");  /*mouse button is pressed*/
            else if (LEFT_PRESS==0)
                WriteScreen(Color4,19,15,"NO ");
			OldLP=LEFT_PRESS;   /* Save LEFT_PRESS condition so next time
								   is not updated unless it has changed */
            }
        if(OldLR!=LEFT_REL)
            {
			if (LEFT_REL==1)                    /*LEFT_REL=1 if left mouse*/
				WriteScreen(Color2,20,15,"YES");/*button has been released */
            else if (LEFT_REL==0)
                WriteScreen(Color4,20,15,"NO ");
            OldLR=LEFT_REL;
            }
        if(OldRP!=RIGHT_PRESS)
            {
			if (RIGHT_PRESS==1)                 /*RIGHT_PRESS=1 if right mouse*/
				WriteScreen(Color2,21,15,"YES");/*button is pressed */
            else if (RIGHT_PRESS==0)
                WriteScreen(Color4,21,15,"NO ");
            OldRP=RIGHT_PRESS;
            }
        if(OldRR!=RIGHT_REL)
            {
			if (RIGHT_REL==1)                   /*RIGHT_REL=1 if right mouse */
				WriteScreen(Color2,22,15,"YES");/*button has been released */
            else if (RIGHT_REL==0)
                WriteScreen(Color4,22,15,"NO ");
            OldRR=RIGHT_REL;
            }
        if(OldMM!=MOUSE_MOVE)
            {
			if (MOUSE_MOVE==1)                  /*MOUSE_MOVE=1 if mouse has*/
				WriteScreen(Color2,23,15,"YES");/*moved since last mouse event*/
            else if (MOUSE_MOVE==0)
                WriteScreen(Color4,23,15,"NO ");
            OldMM=MOUSE_MOVE;
            }
		if (OldLPX!=LPX)                        /*LPX=Mouse X position */
			{                                   /*When the left button was pressed */
			WriteScreen(Color4,19,41,Bin2Ascii((long)LPX,Buffer));
            OldLPX =LPX;
            }
		if (OldLPY!=LPY)                       /*LPY=Mouse Y position*/
			{                                  /*when the left button was released*/
			WriteScreen(Color4,19,66,Bin2Ascii((long)LPY,Buffer));
            OldLPY=LPY;
            }
		if (OldLRX!=LRX)                    /*Left release X position */
            {
			WriteScreen(Color4,20,41,Bin2Ascii((long)LRX,Buffer));
            OldLRX =LRX;
            }
		if (OldLRY!=LRY)                    /*Left release Y position */
            {
			WriteScreen(Color4,20,66,Bin2Ascii((long)LRY,Buffer));
            OldLRY=LRY;
            }
		if (OldRPX!=RPX)                    /*Right press X position */
            {
			WriteScreen(Color4,21,41,Bin2Ascii((long)RPX,Buffer));
            OldRPX =RPX;
            }
		if (OldRPY!=RPY)                    /*Right press Y position */
            {
			WriteScreen(Color4,21,66,Bin2Ascii((long)RPY,Buffer));
            OldRPY=RPY;
            }
		if (OldRRX!=RRX)                    /*Right release X position */
            {
			WriteScreen(Color4,22,41,Bin2Ascii((long)RRX,Buffer));
            OldRRX =RRX;
            }
		if (OldRRY!=RRY)                    /*Right release Y position */
            {
			WriteScreen(Color4,22,66,Bin2Ascii((long)RRY,Buffer));
            OldRRY=RRY;
            }
		if (OldMX!=MOVEX)               /*Mouse actual X position */
            {
			WriteScreen(Color4,23,41,Bin2Ascii((long)MOVEX,Buffer));
            OldMX=MOVEX;
            }
		if (OldMY!=MOVEY)           /*Mouse actual Y position */
            {
			WriteScreen(Color4,23,66,Bin2Ascii((long)MOVEY,Buffer));
            OldMY=MOVEY;
			}

/* Check if a selection has been made in the menu system
   using function MenuSys
	Parameters: Normal Color,Reverse Color,Highlight Color,
				number of pop-up menus, bar menu structure,menu system struc

	Returns 0 if nothing has been selected, either with the mouse or
		the keyboard

	Else returns Menu number followed by menu option selected:

		12 = First menu's second option */


        if(Selection=MenuSys(Color1,Color2,Color3,2,bm,msd))
            {
            switch(Selection)
                {
				case 11:                  /*First menu, first option */
                    EndFlag=1;
                    break;
				case 21:                /*Second Menu first option */
                    PaintFlag=1;
                    break;
				case 22:                /*Second menu, second option */
					Cls(Color4,1,0,14,79);
                }
			}

	/* Check if the QUIT mouse button has been clicked
	CheckMouseButton parameters:
		Number of buttons, mouse button structure
		returns 0 if none has been selected or else
		mouse button number
		*/

        if(LEFT_PRESS && CheckMouseButton(1,mb))
            {
			DrawMouseButton(Color4,Color5,1,1,mb); /*redraw button in case*/
			EndFlag=1;                              /*it was selected*/
			}

   /*Check if the Mouse is moved while the left button is pressed and the
		Paint flag is set */

        if (LEFT_PRESS==1 && LEFT_REL==0 && LPY > 0 && LPY < 14 && PaintFlag==1)
			{

	/* Yes?, paint */

            WriteScreen(Color2,19,15,"YES");
            WriteScreen(Color4,20,15,"NO ");
            HideMouse();
			do                      /* Set X1-Y1 to top left corner */
				{                   /* and X2-Y2 to bottom right corner */
                if (LPX<MOVEX)
                    {
					X1=LPX;
                    X2=MOVEX;
                    }
                else
                    {
                    X1=MOVEX;
                    X2=LPX;
                    }
                if (LPY<MOVEY)
                    {
                    Y1=LPY;
                    Y2=MOVEY;
                    }
                else
                    {
                    Y1=MOVEY;
                    Y2=LPY;
                    }
				if (Y2 > 14)                /* Do not paint menu or box */
                    Y2=14;
                if (Y1==0)
                    Y1=1;
				Cls(Color6,Y1,X1,Y2,X2);    /* Paint Area */
				if (OldMX!=MOVEX)           /* Update MOVEX variable */
                    {
					Cls(Color4,23,41,23,44);
					WriteScreen(Color4,23,41,Bin2Ascii((long)MOVEX,Buffer));
                    OldMX=MOVEX;
                    }
				if (OldMY!=MOVEY)           /* Update MOVEY variable */
                    {
					Cls(Color4,23,66,23,69);
					WriteScreen(Color4,23,66,Bin2Ascii((long)MOVEY,Buffer));
                    OldMY=MOVEY;
                    }
				}while(LEFT_REL==0);    /*Wait for mouse release */
            OldLP=1;
            OldLR=0;
            ShowMouse();
            PaintFlag=0;
            }
		if(KeyReady())      /*Clear key buffer of any unused key */
            {
            if((KeyReady()!=F1) & (KeyReady()!=F2))
                ClearKeyBuf();
            }
        }while(!EndFlag);
	ResetMouse();           /* Reset mouse before exiting */
	}
else                /* No Mouse installed */
    {
    GSSBox(Color5,0,6,29,12,50,1,0,0);
    Shadow(Color2,6,29,12,50);
    WriteScreen(Color5,7,31,"NO MOUSE INSTALLED\n\n  PRESS ANY KEY\n\nTO EXIT MOUSE DEMO");
    GetKey();
    }
Cls(7,0,0,24,79);       /* Clear screen */
CursorOn();             /* Restore cursor */
exit(0);
}

